@@ -5,7 +5,6 @@ import logging
 import click
 import yaml
 from cli import *
-import pprint
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
 
@@ -42,13 +41,12 @@ class NxPyDocs():
                             ]
 
     def nxpydocs(self):
-        pp = pprint.PrettyPrinter(indent=4)
         if self.command == "all":
             for single_command in self.supported_templates:
                 self.command = single_command
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                pp.pprint(json.dumps(parsed_json,indent=4, sort_keys=True))
+                print(json.dumps(parsed_json,indent=4, sort_keys=True))
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
@@ -58,7 +56,7 @@ class NxPyDocs():
             if self.command in self.supported_templates:
                 command_output = clid( '%s' % self.command )
                 parsed_json = json.loads(command_output)
-                pp.pprint(json.dumps(parsed_json,indent=4, sort_keys=True))
+                print(json.dumps(parsed_json,indent=4, sort_keys=True))
                 if "Cannot" in parsed_json:
                     click.secho("No Data To Create File", fg='red')
                 else:
